from pathlib import Path
import os


default_data_dir = Path(os.path.expanduser('~/pymondo_data/'))
resources = ['mondo']


def find(resource, data_dir: Path=None):
    resource = resource.lower()
    assert resource in resources, f'Available resoureces are bellow: {resources}'

    if data_dir is None:
        data_dir = default_data_dir

    fp = data_dir / '{}.json'.format(resource)
    return fp



from pathlib import Path
import requests

from .data import default_data_dir


class Downloader(object):
    def __init__(self, download_dir: Path=None):
        self.download_dir = download_dir
        if self.download_dir is None:
            self.download_dir = default_data_dir
        if not self.download_dir.exists():
            self.download_dir.mkdir()

    def download(self, resource: str):
        print(f'download {resource}')
        fname = f'{resource}.json'
        url = f'http://purl.obolibrary.org/obo/{fname}'
        fp = self.download_dir / fname
        res = requests.get(url)
        with fp.open(mode='wb') as f:
            f.write(res.content)
